@@ -6,7 +6,8 @@ from datetime import timedelta
 from Options import (
     Choice, Toggle, DefaultOnToggle, OptionSet, Range,
     PerGameCommonOptions, Option, VerifyKeys, StartInventory,
-    is_iterable_except_str, OptionGroup, Visibility, ItemDict
+    is_iterable_except_str, OptionGroup, Visibility, ItemDict,
+    Accessibility, ProgressionBalancing
 )
 from Utils import get_fuzzy_results
 from BaseClasses import PlandoOptions
@@ -63,7 +64,7 @@ class Sc2MissionSet(OptionSet):
         return self.value.__len__()
 
 
-class SelectRaces(OptionSet):
+class SelectedRaces(OptionSet):
     """
     Pick which factions' missions and items can be shuffled into the world.
     """
@@ -152,6 +153,7 @@ class MissionOrder(Choice):
     option_golden_path = 10
     option_hopscotch = 11
     option_custom = 99
+    default = option_golden_path
 
 
 class MaximumCampaignSize(Range):
@@ -170,7 +172,7 @@ class TwoStartPositions(Toggle):
     If turned on and 'grid', 'hopscotch', or 'golden_path' mission orders are selected,
     removes the first mission and allows both of the next two missions to be played from the start.
     """
-    display_name = "Start with two unlocked missions on grid"
+    display_name = "Two start missions"
     default = Toggle.option_false
 
 
@@ -251,10 +253,21 @@ class PlayerColorNova(ColorChoice):
 
 
 class EnabledCampaigns(OptionSet):
-    """Determines which campaign's missions will be used"""
+    """
+    Determines which campaign's missions will be used.
+    Wings of Liberty, Prophecy, and Prologue are the only free-to-play campaigns.
+    Valid campaign names:
+    - 'Wings of Liberty'
+    - 'Prophecy'
+    - 'Heart of the Swarm'
+    - 'Whispers of Oblivion (Legacy of the Void: Prologue)'
+    - 'Legacy of the Void'
+    - 'Into the Void (Legacy of the Void: Epilogue)'
+    - 'Nova Covert Ops'
+    """
     display_name = "Enabled Campaigns"
     valid_keys = {campaign.campaign_name for campaign in SC2Campaign if campaign != SC2Campaign.GLOBAL}
-    default = valid_keys
+    default = set((SC2Campaign.WOL.campaign_name,))
 
 
 class EnableRaceSwapVariants(Choice):
@@ -1053,7 +1066,7 @@ class VictoryCache(Range):
     Controls how many additional checks are awarded for completing a mission.
     Goal missions are unaffected by this option.
     """
-    display_name = "Victory Checks"
+    display_name = "Victory Cache"
     range_start = 0
     range_end = 10
     default = 0
@@ -1342,7 +1355,7 @@ class Starcraft2Options(PerGameCommonOptions):
     player_color_zerg: PlayerColorZerg
     player_color_zerg_primal: PlayerColorZergPrimal
     player_color_nova: PlayerColorNova
-    selected_races: SelectRaces
+    selected_races: SelectedRaces
     enabled_campaigns: EnabledCampaigns
     enable_race_swap: EnableRaceSwapVariants
     mission_race_balancing: EnableMissionRaceBalancing
@@ -1436,7 +1449,7 @@ option_groups = [
         ShuffleCampaigns,
         AllInMap,
         TwoStartPositions,
-        SelectRaces,
+        SelectedRaces,
         ExcludeVeryHardMissions,
         EnableMissionRaceBalancing,
     ]),
@@ -1548,7 +1561,7 @@ def get_option_value(world: Union['SC2World', None], name: str) -> int:
 
 
 def get_enabled_races(world: Optional['SC2World']) -> Set[SC2Race]:
-    race_names = world.options.selected_races.value if world and len(world.options.selected_races.value) > 0 else SelectRaces.valid_keys
+    race_names = world.options.selected_races.value if world and len(world.options.selected_races.value) > 0 else SelectedRaces.valid_keys
     return {race for race in SC2Race if race.get_title() in race_names}
 
 
@@ -1744,3 +1757,6 @@ void_trade_age_limits_ms: Dict[int, int] = {
     VoidTradeAgeLimit.option_1_day: 1000 * int(timedelta(days = 1).total_seconds()),
     VoidTradeAgeLimit.option_1_week: 1000 * int(timedelta(weeks = 1).total_seconds()),
 }
+
+# Store the names of all options
+OPTION_NAME = {option_type: name for name, option_type in Starcraft2Options.type_hints.items()}
